@@ -49,11 +49,15 @@ def show_exception_and_exit(exc_type, exc_value, tb):
         return
     import traceback
     traceback.print_exception(exc_type, exc_value, tb)
-    errmsg = "\n".join(traceback.format_exception(exc_type, exc_value, tb))\
+    details = "\n".join(traceback.format_exception(exc_type, exc_value, tb))
+    errmsg = "\n".join(traceback.format_exception_only(exc_type, exc_value))\
             + ("\n The program might misbehave, do you want to continue?")
-    outmsg = QtWidgets.QMessageBox.critical(None, "Exception!", errmsg,
-            QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
-    if outmsg != QtWidgets.QMessageBox.Yes:
+    msgbox = QtWidgets.QMessageBox(
+        3, "Exception!", errmsg,
+        QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
+    msgbox.setDetailedText(details)
+    outvalue = msgbox.exec_()
+    if outvalue != QtWidgets.QMessageBox.Yes:
         sys.exit(-1)
 
 
@@ -274,10 +278,12 @@ def main():
     p_logger = logging.getLogger('parseLogger')
     params_logger = logging.getLogger('acqLogLogger')
     drl_logger = logging.getLogger('drlLogger')
-    zce_logger = logging.getLogger('zceLogger')
+    zce_logger = logging.getLogger('zcelogger')
+    rxn_logger = logging.getLogger('reactivityLogger')
     logging.basicConfig()
     # p_logger.setLevel("WARN")
     p_logger.setLevel("DEBUG")
+    rxn_logger.setLevel("DEBUG")
     # drl_logger.setLevel("INFO")
     drl_logger.setLevel("DEBUG")
     zce_logger.setLevel("DEBUG")
